import {
  select,
  scaleLinear,
  scaleBand,
  axisLeft,
  axisBottom,
} from 'd3';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;
  const margin = {
    top: 100,
    left: 50,
    right: 20,
    bottom: 20,
  };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', 'lightgreen');

  var countries = [
    { country: 'Malta', score: 66 },
    { country: 'Outer Space', score: 33 },
    { country: 'Netherlands', score: 100 },
  ];

  const xValue = (d) => d.country;
  const yValue = (d) => d.score;

  const xScale = scaleBand()
    .domain(countries.map(xValue))
    .range([margin.left, width - margin.right])
    .padding(0.97);

  const yScale = scaleLinear()
    .domain([0, 100])
    .range([innerHeight, 0]);

  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  // STEMS
  const stemWidth = xScale.bandwidth() / 3;
  g.selectAll('rect.stem')
    .data(countries)
    .enter()
    .append('rect')
    .attr('class', 'stem')
    .attr(
      'x',
      (d) =>
        xScale(xValue(d)) +
        xScale.bandwidth() / 2 -
        stemWidth / 2,
    )
    .attr('y', (d) => yScale(yValue(d)))
    .attr('width', stemWidth)
    .attr('height', (d) => innerHeight - yScale(yValue(d)))
    .attr('fill', 'green');

  // FLOWERS AND VASES
  const petalColors = ['blue', 'pink', 'orange'];
  countries.forEach((country, index) => {
    const color = petalColors[index];
    const petalSize = 50;
    const flowerX = xScale(country.country) + 4;
    const flowerY = yScale(country.score);

    // PETALS
    for (let j = 0; j < 5; j++) {
      const angle = ((Math.PI * 2) / 5) * j - 180;
      const petalX =
        flowerX + Math.cos(angle) * petalSize * 0.8;
      const petalY =
        flowerY + Math.sin(angle) * petalSize * 0.8;
      g.append('circle')
        .attr('cx', petalX)
        .attr('cy', petalY)
        .attr('r', petalSize / 3.2)
        .attr('fill', color);
    }

    // CENTER
    g.append('circle')
      .attr('cx', flowerX)
      .attr('cy', flowerY)
      .attr('r', petalSize / 3.2)
      .attr('fill', 'yellow');

    g.append('circle')
      .attr('cx', flowerX)
      .attr('cy', flowerY)
      .attr('r', 5)
      .attr('fill', 'green');

    // VASE
    const vaseWidth = 20;
    const vaseHeight = 80;
    const vaseX =
      xScale(country.country) +
      xScale.bandwidth() / 2 -
      vaseWidth / 2;
    const vaseY =
      yScale(country.score) + petalSize / 3.2 + 5; // Place vase below the flower
    g.append('rect')
      .attr('x', vaseX)
      .attr('y', vaseY)
      .attr('width', vaseWidth)
      .attr('height', vaseHeight)
      .attr('fill', 'brown');
  });
};
